<?php

namespace App\Controller;

use App\Entity\User;
use App\Form\SecuritySignInForm;
use App\Form\SecuritySignUpForm;
use Exception;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Authentication\AuthenticationUtils;

/**
 * Controller about security (login / logout)
 *
 * @package App\Controller
 */
class SecurityController extends AbstractController {
    /**
     * Show login form
     *
     * @param AuthenticationUtils $authenticationUtils Helper for authentication information
     *
     * @return Response Page response
     *
     * @Route("/sign-in")
     */
    public function sign_in (AuthenticationUtils $authenticationUtils): Response {
        $form = $this->createForm(
            SecuritySignInForm::class,
            [
                'email' => $authenticationUtils->getLastUsername(),
            ]
        );

        return $this->render(
            'security/sign-in.html.twig',
            [
                'error' => $authenticationUtils->getLastAuthenticationError(),
                'form'  => $form->createView(),
            ]
        );
    }

    /**
     * *Perform* logout
     *
     * @throws Exception When firewall failed and this method is *really* called
     *
     * @Route("/sign-out")
     */
    public function sign_out () {
        throw new Exception('This method can be blank - it will be intercepted by the logout key on your firewall');
    }

    /**
     * Show inscription form
     *
     * @param Request $request The request object
     *
     * @return Response Page response
     *
     * @Route("/sign-up")
     */
    public function sign_up (Request $request) {
        $user = new User();
        $user->setLanguage($request->getLocale());

        $form = $this->createForm(SecuritySignUpForm::class, $user);

        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $user = $form->getData();

            $doctrine = $this->getDoctrine()->getManager();
            $doctrine->persist($user);
            $doctrine->flush();

            return $this->redirectToRoute('app_security_sign_in');
        }

        return $this->render(
            'security/sign-up.html.twig',
            [
                'form' => $form->createView(),
            ]
        );
    }
}
