<?php

namespace App\Form;

use App\Entity\User;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\LanguageType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\RepeatedType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Contracts\Translation\TranslatorInterface;
use Vich\UploaderBundle\Form\Type\VichImageType;

/**
 * Security : sign-up form
 *
 * @package App\Form
 */
class SecuritySignUpForm extends AbstractBootstrapForm {
    /**
     * @var TranslatorInterface The translation service
     */
    private TranslatorInterface $translatorInterface;

    /**
     * Class constructor
     *
     * Called using auto-wiring
     *
     * @param TranslatorInterface $translatorInterface The translation service
     */
    public function __construct (TranslatorInterface $translatorInterface) {
        $this->translatorInterface = $translatorInterface;
    }

    /**
     * @inheritDoc
     */
    public function buildForm (FormBuilderInterface $builder, array $options) {
        parent::buildForm($builder, $options);

        $builder
            ->add(
                'email',
                EmailType::class,
                [
                    'label_format' => 'user.email',
                ]
            )
            ->add(
                'plainPassword',
                RepeatedType::class,
                [
                    'type'           => PasswordType::class,
                    'first_options'  => [
                        'label_format' => 'user.password',
                    ],
                    'second_options' => [
                        'label_format' => 'user.password_confirm',
                    ],
                ]
            )
            ->add(
                'gender',
                ChoiceType::class,
                [
                    'choices'                   => User::getGenders(),
                    'choice_label'              => function (string $gender) {
                        return $gender ? $this->translatorInterface->trans('user.genders.' . $gender, [], 'security') : '';
                    },
                    'choice_translation_domain' => false,
                    'label_format'              => 'user.gender',
                    'required'                  => false,
                ]
            )
            ->add(
                'firstname',
                TextType::class,
                [
                    'label_format' => 'user.firstname',
                    'required'     => false,
                ]
            )
            ->add(
                'name',
                TextType::class,
                [
                    'label_format' => 'user.name',
                ]
            )
            ->add(
                'language',
                LanguageType::class,
                [
                    'choice_self_translation' => true,
                    'label_format'            => 'user.language',
                ]
            )
            ->add(
                'avatarFile',
                VichImageType::class,
                [
                    'label_format'           => 'user.avatar',
                    'translation_domain'     => 'security',
                    'required'               => false,
                    'imagine_pattern'        => 'url_avatar',
                    'storage_resolve_method' => VichImageType::STORAGE_RESOLVE_PATH_RELATIVE,
                ]
            );
    }

    /**
     * @inheritDoc
     */
    public function configureOptions (OptionsResolver $resolver) {
        parent::configureOptions($resolver);

        $resolver->setDefaults(
            [
                'translation_domain' => 'security',
                'data_class'         => User::class,
            ]
        );
    }
}